CLIError

Trait CLIError 

pub trait CLIError: From<Error> {
    // Required method
    fn no_such_entity(ename: &'static str, query: String) -> Self;
}
Trait used to expose errors from the autogenerated clap interface code. Implemented for Error but can be implemented for other error types if extra information needs to be passed back.

Required Methods

fn no_such_entity(ename: &'static str, query: String) -> Self

Complain about an entity by a given list of members not existing.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors