pub enum LocalSide {
Domain,
Range,
}Expand description
Enumeration used to represent which side of a relation a Relation trait implementation is representing.
Variants
Domain
The side of the relation that the Relation represents is the Domain side.
Range
The side of the relation that the Relation represents is the Range side.